==> mysql-community_8.0.25.orig.tar.gz: mysql-8.0.25/storage/ndb/src/ndbjtie/com/mysql/ndbjtie/ndbapi/NdbIndexOperation.java <==
/*
  Copyright (c) 2010, 2021, Oracle and/or its affiliates.
  Use is subject to license terms.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * NdbIndexOperation.java
 */

package com.mysql.ndbjtie.ndbapi;

import java.nio.ByteBuffer;

import com.mysql.jtie.Wrapper;

public class NdbIndexOperation extends NdbOperation implements NdbIndexOperationConst
{
    public final native NdbDictionary.IndexConst/*_const NdbDictionary.Index *_*/ getIndex() /*_const_*/;
    public final native int insertTuple();
    public final native int readTuple(int/*_LockMode_*/ p0);
    public final native int updateTuple();
    public final native int deleteTuple();
}

==> mysql-community_8.4.0.orig.tar.gz: mysql-8.4.0/storage/ndb/src/ndbjtie/com/mysql/ndbjtie/ndbapi/NdbIndexOperation.java <==
/*
  Copyright (c) 2010, 2024, Oracle and/or its affiliates.
  Use is subject to license terms.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * NdbIndexOperation.java
 */

package com.mysql.ndbjtie.ndbapi;

import java.nio.ByteBuffer;

import com.mysql.jtie.Wrapper;

public class NdbIndexOperation extends NdbOperation implements NdbIndexOperationConst
{
    public final native NdbDictionary.IndexConst/*_const NdbDictionary.Index *_*/ getIndex() /*_const_*/;
    public final native int insertTuple();
    public final native int readTuple(int/*_LockMode_*/ p0);
    public final native int updateTuple();
    public final native int deleteTuple();
}
